@@ -28,7 +28,7 @@ copyright = u'2017-2021, OpenTelekomCloud Contributors'
 exclude_patterns = ['_build']
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+# pygments_style = 'sphinx'
 
 
 # -- Options for HTML output ----------------------------------------------
